Documentation
¶
Overview ¶
Package notify provides functionality to send, edit, and delete notifications in various messaging platforms, including Discord and Telegram.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Discord ¶
type Discord struct {
// contains filtered or unexported fields
}
Discord represents a client for interacting with Discord webhooks.
func NewDiscord ¶
NewDiscord creates a new instance of a Discord client.
Parameters:
- webhookID: The Discord webhook ID.
- webhookToken: The Discord webhook token.
Returns:
- A pointer to a Discord instance.
func (*Discord) Delete ¶
Delete removes an existing message from a Discord channel.
Parameters:
- id: The ID of the message to delete.
Returns:
- An error if the operation fails.
type Telegram ¶
type Telegram struct {
// contains filtered or unexported fields
}
Telegram represents a client for interacting with the Telegram Bot API.
func NewTelegram ¶
NewTelegram creates a new instance of a Telegram client.
Parameters:
- chatID: The chat ID where messages will be sent.
- botToken: The Telegram bot token.
Returns:
- A pointer to a Telegram instance.
func (*Telegram) Delete ¶
Delete removes an existing message from a Telegram chat.
Parameters:
- id: The ID of the message to delete.
Returns:
- An error if the operation fails.
Click to show internal directories.
Click to hide internal directories.